<template>
  <ContentScrollView hasPaddingTop style="background-color: transparent">
    <PhoneBillRecharge
      @goPay="goPay"
      :isDev="isDev"
      @paySuccess="handePaySuccess"
      :getOpenId="ensureOpenId"
      :isInWeChat="isInWeChat"
      :isInAlipay="isInAlipay"
      :isH5="isWeb"
      :appId="WXPayAppId"
      :isFocus="isFocus"
      :showAliPay="!isInWeChat"
      :showWeixinPay="isInWeChat"
      @missName="handleMissName"
    />
  </ContentScrollView>
</template>

<script setup lang="ts">
import { PhoneBillRecharge } from '@life-payment/components';
import { BlLifeRecharge } from '@life-payment/core-vue';
import Taro from '@tarojs/taro';
import { isInAlipay, isInWeChat, isH5, isWeb } from '@/utils/env';
import { useUser, useFocus, useEnsureOpenId } from '@/hooks';
import { WXPayAppId } from '@/constants';
import { Message } from '@/utils';

defineOptions({
  name: 'InnerPage',
});

const isDev = process.env.NODE_ENV === 'development';

const { wxOpenId } = useUser();
const { ensureOpenId } = useEnsureOpenId();
const { isFocus } = useFocus();

function goPay(orderNo: string) {
  RouteHelper.navigateTo({
    url: `${RouterPath.selectPayType}?orderNo=${orderNo}&lifePayOrderType=${BlLifeRecharge.constants.LifePayOrderTypeEnum.话费订单}`,
  });
}

function handePaySuccess(orderNo: string) {
  RouteHelper.navigateTo({
    url: `${RouterPath.rechargeResult}?orderNo=${orderNo}&lifePayOrderType=${BlLifeRecharge.constants.LifePayOrderTypeEnum.话费订单}`,
  });
}

async function handleMissName(userAccountId: string) {
  try {
    await Message.confirm({ message: '请先完善手机号所属机主姓名' });
    RouteHelper.navigateTo({
      url: `${RouterPath.editPhoneUserAccount}?id=${userAccountId}`,
    });
  } catch (error) {}
}
</script>
